package
Version:
v0.9.3
Opens a new window with list of versions in this module.
Published: May 30, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetFileHash はファイルのMD5ハッシュを計算する
GitRoot は指定ディレクトリの Git リポジトリルートを返す
type Worktree struct {
Name string `json:"name"`
Path string `json:"path"`
Current bool `json:"current"`
FileHash *string `json:"fileHash,omitempty"`
}
Worktree はgit worktreeの情報を表す
FindByName は名前でworktreeを検索する
List は指定されたパスのgitリポジトリに関連するworktree一覧を返す
ListWithHashes はworktree一覧を返し、指定されたファイルパスのハッシュを含める。
relSubdir は basePath(git root)からユーザーが指定したルートまでの相対パス。
"."(または空文字)なら git root をそのまま basePath とみなす。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.